@@ -209,6 +209,7 @@ class NavSoapClient():
         serialized_response = serialize_object(soap_response)
         return serialized_response
 
+
     def get_item_images(self, item_number):
         """
         Returns a base64 encoded string that represents the image for
@@ -228,3 +229,21 @@ class NavSoapClient():
 
         serialized_response = serialize_object(soap_response)
         return serialized_response
+
+
+    def update_alert_output(self):
+        """
+        Remotely triggers Microsoft NAV's Alert Output job.
+        """
+        session = Session()
+        session.auth = HTTPBasicAuth(self.nav_user, self.nav_password)
+
+        soap_service_url = self.nav_soap_service + \
+            self.nav_company + "/Codeunit/SiteManagementWS"
+        client = Client(soap_service_url, transport=Transport(
+            session=session, cache=SqliteCache()))
+
+        soap_response = client.service.UpdateAlertOutput()
+
+        serialized_response = serialize_object(soap_response)
+        return serialized_response
